(define-module (ui openvpn-server clients ajax)
			   :use-module (alterator ajax)
			   :use-module (alterator woo)
			   :export (init))

(define (read-client client)
  (catch/message
	(lambda()
	  (and client
		   (not (string=? client ""))
		   (begin
			 (let* ((cmd (woo-read-first "/openvpn-server" 'client_name client))
					(networks (woo-list "/openvpn-server/avail_clients_networks" 'client_name client))
					(first-value (if (null? networks) #f (woo-get-option (car networks) 'name))))
			   (form-update-enum "clients_networks" networks)
			   (form-update-value "client_name" client)
			   (form-update-value "clients" client)
			   (form-update-value "clients_networks" first-value)
			   (form-update-value-list '("client_ns" "client_domain") cmd)
			   (update-client-interface first-value)))))))

(define (update-interface client)
  (form-update-enum "clients" (woo-list "/openvpn-server/avail_clients"))
  (form-update-enum "client_netmask" (woo-list "/openvpn-server/avail_masks"))
  (read-client client))

(define (update-client-interface network)
  (and network
	   (begin
		 (form-update-value "client_net" (car (string-split network #\/))) 
		 (form-update-value "client_netmask" (cadr (string-split network #\/))))))

(define (write-config reason)
  (catch/message
	(lambda()
	  (apply woo-write
			 "/openvpn-server"
			 'operation reason
			 (form-value-list
			   '("client_name" "client_net" "client_netmask" "client_ns" "client_domain"))))))

(define (add-client-network)
  (write-config "add-client-network")
  (update-interface (form-value "client_name")))

(define (remove-client-network)
  (write-config "remove-client-network")
  (update-interface (form-value "client_name")))

(define (back)
  (form-replace "/openvpn-server"))

(define (init)
  (update-interface "")
  (form-bind "clients" "change" (lambda() (read-client (form-value "clients"))))
  (form-bind "clients_networks" "change" (lambda() (update-client-interface (form-value "clients_networks"))))
  (form-bind "add_network" "click" add-client-network)
  (form-bind "remove_network" "click" remove-client-network)
  (form-bind "back" "click" back))

